==> faxtomail-ui-swing-0.1-sources.jar: com/franciaflex/faxtomail/ui/swing/util/FaxToMailExceptionHandler.java <==
package com.franciaflex.faxtomail.ui.swing.util;

/*
 * #%L
 * FaxToMail :: UI
 * %%
 * Copyright (C) 2014 Franciaflex
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.ui.swing.actions.AbstractChangeScreenAction;
import com.franciaflex.faxtomail.ui.swing.actions.AbstractFaxToMailAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.jaxx.application.swing.action.ApplicationActionException;
import org.nuiton.jaxx.application.swing.util.ApplicationErrorHelper;
import org.nuiton.jaxx.application.swing.util.ApplicationExceptionHandler;

/**
 * FaxToMail global exception handler.
 * <p/>
 * Catch all application uncaught and display it in a custom JoptionPane
 * or JXErrorPane.
 * <p/>
 * See http://stackoverflow.com/a/4448569/1165234 for details.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class FaxToMailExceptionHandler extends ApplicationExceptionHandler {

    private static final Log log =
            LogFactory.getLog(FaxToMailExceptionHandler.class);

    public FaxToMailExceptionHandler(ApplicationErrorHelper errorHelper) {
        super(errorHelper);
    }

    protected void handleException(String tname, Throwable ex) {
        if (log.isErrorEnabled()) {
            log.error("Global application exception [" + tname + "]", ex);
        }

        Throwable cause = getCause(ex);

        boolean backToScreen = false;

        AbstractFaxToMailAction action = null;

        if (cause instanceof ApplicationActionException) {

            ApplicationActionException actionException = (ApplicationActionException) cause;
            cause = cause.getCause();

            if (log.isDebugEnabled()) {
                log.debug("Action error cause:", cause);
            }

            action = (AbstractFaxToMailAction) actionException.getAction();

            if (action instanceof AbstractChangeScreenAction) {
                backToScreen = true;
            }
        }

        showErrorDialog(cause.getMessage(), cause);

        if (backToScreen) {

//            action.getContext().setFallBackScreen();
        }
    }

}

==> faxtomail-ui-swing-1.0-sources.jar: com/franciaflex/faxtomail/ui/swing/util/FaxToMailExceptionHandler.java <==
package com.franciaflex.faxtomail.ui.swing.util;

/*
 * #%L
 * FaxToMail :: UI
 * %%
 * Copyright (C) 2014 Mac-Groupe, Code Lutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.franciaflex.faxtomail.ui.swing.actions.AbstractChangeScreenAction;
import com.franciaflex.faxtomail.ui.swing.actions.AbstractFaxToMailAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.nuiton.jaxx.application.swing.action.ApplicationActionException;
import org.nuiton.jaxx.application.swing.util.ApplicationErrorHelper;
import org.nuiton.jaxx.application.swing.util.ApplicationExceptionHandler;

/**
 * FaxToMail global exception handler.
 * 
 * Catch all application uncaught and display it in a custom JoptionPane
 * or JXErrorPane.
 * 
 * See http://stackoverflow.com/a/4448569/1165234 for details.
 *
 * @author kmorin - morin@codelutin.com
 */
public class FaxToMailExceptionHandler extends ApplicationExceptionHandler {

    private static final Log log =
            LogFactory.getLog(FaxToMailExceptionHandler.class);

    public FaxToMailExceptionHandler(ApplicationErrorHelper errorHelper) {
        super(errorHelper);
    }

    protected void handleException(String tname, Throwable ex) {
        if (log.isErrorEnabled()) {
            log.error("Global application exception [" + tname + "]", ex);
        }

        Throwable cause = getCause(ex);

        boolean backToScreen = false;

        AbstractFaxToMailAction action = null;

        if (cause instanceof ApplicationActionException) {

            ApplicationActionException actionException = (ApplicationActionException) cause;
            cause = cause.getCause();

            if (log.isDebugEnabled()) {
                log.debug("Action error cause:", cause);
            }

            action = (AbstractFaxToMailAction) actionException.getAction();

            if (action instanceof AbstractChangeScreenAction) {
                backToScreen = true;
            }
        }

        showErrorDialog(cause != null ? cause.getMessage() : "", cause);

        if (backToScreen) {

//            action.getContext().setFallBackScreen();
        }
    }

}
